"use strict";
var index_1 = require('../index');
var assert = require('assert');
var is = require('is');
var apiKey = 'EPxw660Rph7IjQJhQz9ZgdS2h3YR7Hm4oXfIiQEfTG5rvZalqVR6';
describe('Geopromos JS SDK', function () {
    describe('#initialize()', function () {
        it('should not throw', function () {
            assert.doesNotThrow(function () {
                index_1.Geopromos.initialize(apiKey);
            });
        });
    });
    describe('this api call should work', function () {
        it('should work', function (done) {
            index_1.Geopromos.getCategories()
                .then(function (cat) {
                assert.ok(cat);
                done();
            });
        });
    });
    describe('#getCategories', function () {
        var categories;
        before(function () {
            return new Promise(function (resolve, reject) {
                index_1.Geopromos.getCategories()
                    .then(function (c) {
                    categories = c;
                    resolve();
                }, reject);
            });
        });
        it('should return an array', function () {
            assert.ok(is.array(categories));
        });
        it('each category should have an alias and a defaultName', function () {
            var is = true;
            categories.forEach(function (c) {
                if (!c.alias || !c.defaultName) {
                    is = false;
                }
            });
            assert.ok(is);
        });
    });
    describe('#getSubcategories', function () {
        var subcategories;
        before(function () {
            return new Promise(function (resolve, reject) {
                index_1.Geopromos.getCategories()
                    .then(function (c) {
                    subcategories = c;
                    resolve();
                }, reject);
            });
        });
        it('should return an array', function () {
            assert.ok(is.array(subcategories));
        });
        it('each category should have an alias and a defaultName', function () {
            var is = true;
            subcategories.forEach(function (c) {
                if (!c.alias || !c.defaultName) {
                    is = false;
                }
            });
            assert.ok(is);
        });
    });
    describe('#getMall', function () {
        var mall;
        before(function () {
            return new Promise(function (resolve, reject) {
                index_1.Geopromos.getMall('G4EuyQLGM9')
                    .then(function (c) {
                    mall = c;
                    resolve();
                }, reject);
            });
        });
        it('should return an object', function () {
            assert.ok(is.object(mall));
        });
        ;
        (['name', 'location', 'objectId']).forEach(function (param) {
            it('object returned should have param ' + param, function () {
                assert.ok(mall[param]);
            });
        });
    });
    describe('#getProduct', function () {
        var item;
        before(function () {
            return new Promise(function (resolve, reject) {
                index_1.Geopromos.getProduct('HX9RAuPEUd')
                    .then(function (c) {
                    item = c;
                    resolve();
                }, reject);
            });
        });
        it('should return an object', function () {
            assert.ok(is.object(item));
        });
        ;
        (['defaultName', 'brand', 'objectId']).forEach(function (param) {
            it('object returned should have param ' + param, function () {
                assert.ok(item[param]);
            });
        });
    });
    describe('#getPromo', function () {
        var item;
        before(function () {
            return new Promise(function (resolve, reject) {
                index_1.Geopromos.getPromo('gXR745XpGe')
                    .then(function (c) {
                    item = c;
                    resolve();
                }, reject);
            });
        });
        it('should return an object', function () {
            assert.ok(is.object(item));
        });
        ;
        (['name', 'brand', 'objectId']).forEach(function (param) {
            it('object returned should have param ' + param, function () {
                assert.ok(item[param]);
            });
        });
    });
    describe('#getStore', function () {
        var item;
        before(function () {
            return new Promise(function (resolve, reject) {
                index_1.Geopromos.getStore('WgzdiAcTOv')
                    .then(function (c) {
                    item = c;
                    resolve();
                }, reject);
            });
        });
        it('should return an object', function () {
            assert.ok(is.object(item));
        });
        ;
        (['name', 'brand', 'objectId']).forEach(function (param) {
            it('object returned should have param ' + param, function () {
                assert.ok(item[param]);
            });
        });
    });
    describe('#getTrends', function () {
        var response;
        var limit = Math.floor(Math.random() * 10 + 2);
        before(function () {
            return new Promise(function (resolve, reject) {
                var possibilities = [
                    index_1.Geopromos.getTrends({ lat: 3.551115, lng: -76.585693, limit: limit }),
                    index_1.Geopromos.getTrends({ countryCode: 'CO', limit: limit }),
                    index_1.Geopromos.getTrends()
                ];
                possibilities[Math.floor(Math.random() * possibilities.length)]
                    .then(function (e) {
                    response = e;
                    resolve();
                }, reject);
            });
        });
        it('should return an array', function () {
            assert.ok(is.array(response));
        });
        it('response should have a length <= ' + limit, function () {
            assert.ok(response.length <= limit);
        });
    });
    describe('#search', function () {
        var q = "#blackfriday";
        var results;
        var limit = 10;
        describe('searching with lat & lng', function () {
            this.timeout(5000);
            before(function () {
                return new Promise(function (resolve, reject) {
                    index_1.Geopromos.search({
                        q: q,
                        lat: 4.684465,
                        lng: -74.074802,
                        limit: limit
                    }).then(function (res) {
                        results = res;
                        resolve();
                    }, reject);
                });
            });
            it('results returned should be an array', function () {
                assert.ok(is.array(results));
            });
            it('results returned should be no more than ' + limit, function () {
                assert.ok(results.length <= limit);
            });
            it('results returned should say what type are them', function () {
                var passes = true;
                results.forEach(function (res) {
                    if (!res.type) {
                        passes = false;
                    }
                });
                assert.ok(passes);
            });
        });
        describe('searching without lat lng', function () {
            this.timeout(5000);
            before(function () {
                return new Promise(function (resolve, reject) {
                    index_1.Geopromos.search({
                        q: q,
                        limit: limit
                    }).then(function (res) {
                        results = res;
                        resolve();
                    }, reject);
                });
            });
            it('results returned should be an array', function () {
                assert.ok(is.array(results));
            });
            it('results returned should be no more than ' + limit, function () {
                assert.ok(results.length <= limit);
            });
            it('results returned should say what type are them', function () {
                var passes = true;
                results.forEach(function (res) {
                    if (!res.type) {
                        passes = false;
                    }
                });
                assert.ok(passes);
            });
        });
    });
});
